@@ -1,11 +1,9 @@
 use std::{env, io};
 
-use futures::StreamExt;
+use futures_util::StreamExt;
 use log::info;
-use ntex::http::header::HeaderValue;
-use ntex::http::{HttpService, Request, Response};
-use ntex::server::Server;
-use ntex::util::BytesMut;
+use ntex::http::{header::HeaderValue, HttpService, Request, Response};
+use ntex::{server::Server, util::BytesMut};
 
 async fn handle_request(mut req: Request) -> Result<Response, io::Error> {
     let mut body = BytesMut::new();
@@ -25,8 +23,8 @@ async fn main() -> io::Result<()> {
     env_logger::init();
 
     Server::build()
-        .bind("echo", "127.0.0.1:8080", || {
-            HttpService::build().finish(handle_request).tcp()
+        .bind("echo", "127.0.0.1:8080", |_| {
+            HttpService::build().finish(handle_request)
         })?
         .run()
         .await
