@@ -1,7 +1,7 @@
 //! HTTP Client
 //!
 //! ```rust
-//! use futures::future::{lazy, Future};
+//! use futures_util::future::{lazy, Future};
 //! use ntex::http::client::Client;
 //!
 //! #[ntex::main]
@@ -31,10 +31,8 @@ mod request;
 mod response;
 mod sender;
 mod test;
-pub mod ws;
 
 pub use self::builder::ClientBuilder;
-pub use self::connect::BoxedSocket;
 pub use self::connection::Connection;
 pub use self::connector::Connector;
 pub use self::frozen::{FrozenClientRequest, FrozenSendBuilder};
@@ -47,7 +45,7 @@ use crate::http::error::HttpError;
 use crate::http::{HeaderMap, Method, RequestHead, Uri};
 use crate::time::Millis;
 
-use self::connect::{Connect as InnerConnect, ConnectorWrapper};
+use self::connect::{Connect as HttpConnect, ConnectorWrapper};
 
 #[derive(Clone)]
 pub struct Connect {
@@ -76,7 +74,7 @@ pub struct Connect {
 pub struct Client(Rc<ClientConfig>);
 
 pub(self) struct ClientConfig {
-    pub(self) connector: Box<dyn InnerConnect>,
+    pub(self) connector: Box<dyn HttpConnect>,
     pub(self) headers: HeaderMap,
     pub(self) timeout: Millis,
 }
@@ -194,17 +192,4 @@ impl Client {
     {
         self.request(Method::OPTIONS, url)
     }
-
-    /// Construct WebSockets request.
-    pub fn ws<U>(&self, url: U) -> ws::WsRequest
-    where
-        Uri: TryFrom<U>,
-        <Uri as TryFrom<U>>::Error: Into<HttpError>,
-    {
-        let mut req = ws::WsRequest::new(url, self.0.clone());
-        for (key, value) in self.0.headers.iter() {
-            req.head.headers.insert(key.clone(), value.clone());
-        }
-        req
-    }
 }
