@@ -19,7 +19,6 @@ pub mod h1;
 pub mod h2;
 pub mod header;
 pub mod test;
-pub mod ws;
 
 pub(crate) use self::message::Message;
 
@@ -38,10 +37,4 @@ pub use self::service::HttpService;
 // re-exports
 pub use http::uri::{self, Uri};
 pub use http::{Method, StatusCode, Version};
-
-/// Http protocol
-#[derive(Copy, Clone, Debug, PartialEq, Eq, Hash)]
-pub enum Protocol {
-    Http1,
-    Http2,
-}
+pub use ntex_tls::types::HttpProtocol;
