@@ -1,15 +1,13 @@
 //! Test helpers to use during testing.
-use std::{convert::TryFrom, io, net, str::FromStr, sync::mpsc, thread};
+use std::{convert::TryFrom, net, str::FromStr, sync::mpsc, thread};
 
 #[cfg(feature = "cookie")]
 use coo_kie::{Cookie, CookieJar};
 
-use crate::codec::{AsyncRead, AsyncWrite, Framed};
-use crate::rt::{net::TcpStream, System};
-use crate::server::{Server, StreamServiceFactory};
+use crate::ws::{error::WsClientError, WsClient, WsConnection};
+use crate::{io::Filter, io::Io, rt::System, server::Server, service::ServiceFactory};
 use crate::{time::Millis, time::Seconds, util::Bytes};
 
-use super::client::error::WsClientError;
 use super::client::{Client, ClientRequest, ClientResponse, Connector};
 use super::error::{HttpError, PayloadError};
 use super::header::{HeaderMap, HeaderName, HeaderValue};
@@ -129,6 +127,7 @@ impl TestRequest {
         self
     }
 
+    /// Take test request
     pub fn take(&mut self) -> TestRequest {
         TestRequest(self.0.take())
     }
@@ -157,8 +156,7 @@ impl TestRequest {
             let mut cookie = String::new();
             for c in inner.cookies.delta() {
                 let name = percent_encode(c.name().as_bytes(), super::helpers::USERINFO);
-                let value =
-                    percent_encode(c.value().as_bytes(), super::helpers::USERINFO);
+                let value = percent_encode(c.value().as_bytes(), super::helpers::USERINFO);
                 let _ = write!(&mut cookie, "; {}={}", name, value);
             }
             if !cookie.is_empty() {
@@ -207,26 +205,29 @@ fn parts(parts: &mut Option<Inner>) -> &mut Inner {
 ///     assert!(response.status().is_success());
 /// }
 /// ```
-pub fn server<F: StreamServiceFactory<TcpStream>>(factory: F) -> TestServer {
+pub fn server<F, R>(factory: F) -> TestServer
+where
+    F: Fn() -> R + Send + Clone + 'static,
+    R: ServiceFactory<Io>,
+{
     let (tx, rx) = mpsc::channel();
 
     // run server in separate thread
     thread::spawn(move || {
-        let mut sys = System::new("test-server");
+        let sys = System::new("test-server");
         let tcp = net::TcpListener::bind("127.0.0.1:0").unwrap();
         let local_addr = tcp.local_addr().unwrap();
 
-        sys.exec(|| {
+        tx.send((sys.system(), local_addr)).unwrap();
+
+        sys.run(|| {
             Server::build()
-                .listen("test", tcp, factory)?
+                .listen("test", tcp, move |_| factory())?
                 .workers(1)
                 .disable_signals()
-                .start();
-            Ok::<_, io::Error>(())
-        })?;
-
-        tx.send((System::current(), local_addr)).unwrap();
-        sys.run()
+                .run();
+            Ok(())
+        })
     });
 
     let (system, addr) = rx.recv().unwrap();
@@ -235,7 +236,7 @@ pub fn server<F: StreamServiceFactory<TcpStream>>(factory: F) -> TestServer {
         let connector = {
             #[cfg(feature = "openssl")]
             {
-                use open_ssl::ssl::{SslConnector, SslMethod, SslVerifyMode};
+                use tls_openssl::ssl::{SslConnector, SslMethod, SslVerifyMode};
 
                 let mut builder = SslConnector::builder(SslMethod::tls()).unwrap();
                 builder.set_verify(SslVerifyMode::NONE);
@@ -317,23 +318,56 @@ impl TestServer {
         response.body().limit(10_485_760).await
     }
 
+    /// Connect to a websocket server
+    pub async fn ws(&mut self) -> Result<WsConnection<impl Filter>, WsClientError> {
+        self.ws_at("/").await
+    }
+
     /// Connect to websocket server at a given path
     pub async fn ws_at(
         &mut self,
         path: &str,
-    ) -> Result<Framed<impl AsyncRead + AsyncWrite, crate::ws::Codec>, WsClientError>
-    {
-        let url = self.url(path);
-        let connect = self.client.ws(url).connect();
-        connect.await.map(|ws| ws.into_inner().1)
+    ) -> Result<WsConnection<impl Filter>, WsClientError> {
+        WsClient::build(self.url(path))
+            .address(self.addr)
+            .timeout(Seconds(30))
+            .finish()
+            .unwrap()
+            .connect()
+            .await
     }
 
+    #[cfg(feature = "openssl")]
     /// Connect to a websocket server
-    pub async fn ws(
+    pub async fn wss(
         &mut self,
-    ) -> Result<Framed<impl AsyncRead + AsyncWrite, crate::ws::Codec>, WsClientError>
-    {
-        self.ws_at("/").await
+    ) -> Result<WsConnection<crate::connect::openssl::SslFilter>, WsClientError> {
+        self.wss_at("/").await
+    }
+
+    #[cfg(feature = "openssl")]
+    /// Connect to secure websocket server at a given path
+    pub async fn wss_at(
+        &mut self,
+        path: &str,
+    ) -> Result<WsConnection<crate::connect::openssl::SslFilter>, WsClientError> {
+        use tls_openssl::ssl::{SslConnector, SslMethod, SslVerifyMode};
+
+        let mut builder = SslConnector::builder(SslMethod::tls()).unwrap();
+        builder.set_verify(SslVerifyMode::NONE);
+        let _ = builder
+            .set_alpn_protos(b"\x08http/1.1")
+            .map_err(|e| log::error!("Cannot set alpn protocol: {:?}", e));
+
+        WsClient::build(self.url(path))
+            .address(self.addr)
+            .timeout(Seconds(30))
+            .openssl(builder.build())
+            .take()
+            .finish()
+            .unwrap()
+            .connect()
+            .await
     }
 
     /// Stop http server
