@@ -1,13 +1,11 @@
 //! Payload/Bytes/String extractors
 use std::{future::Future, pin::Pin, str, task::Context, task::Poll};
 
-use bytes::{Bytes, BytesMut};
 use encoding_rs::UTF_8;
-use futures_core::Stream;
 use mime::Mime;
 
 use crate::http::{error, header, HttpMessage};
-use crate::util::{next, Either, Ready};
+use crate::util::{next, Bytes, BytesMut, Either, Ready, Stream};
 use crate::web::error::{ErrorRenderer, PayloadError};
 use crate::web::{FromRequest, HttpRequest};
 
@@ -16,8 +14,8 @@ use crate::web::{FromRequest, HttpRequest};
 /// ## Example
 ///
 /// ```rust
-/// use bytes::BytesMut;
-/// use futures::{Future, Stream};
+/// use std::future::Future;
+/// use ntex::util::{BytesMut, Stream};
 /// use ntex::web::{self, error, App, HttpResponse};
 ///
 /// /// extract binary data from request
@@ -66,8 +64,8 @@ impl Stream for Payload {
 /// ## Example
 ///
 /// ```rust
-/// use bytes::BytesMut;
-/// use futures::{Future, Stream};
+/// use std::future::Future;
+/// use ntex::util::{BytesMut, Stream};
 /// use ntex::web::{self, error, App, Error, HttpResponse};
 ///
 /// /// extract binary data from request
@@ -94,10 +92,7 @@ impl<Err: ErrorRenderer> FromRequest<Err> for Payload {
     type Future = Ready<Payload, Self::Error>;
 
     #[inline]
-    fn from_request(
-        _: &HttpRequest,
-        payload: &mut crate::http::Payload,
-    ) -> Self::Future {
+    fn from_request(_: &HttpRequest, payload: &mut crate::http::Payload) -> Self::Future {
         Ready::Ok(Payload(payload.take()))
     }
 }
@@ -112,8 +107,7 @@ impl<Err: ErrorRenderer> FromRequest<Err> for Payload {
 /// ## Example
 ///
 /// ```rust
-/// use bytes::Bytes;
-/// use ntex::web;
+/// use ntex::{web, util::Bytes};
 ///
 /// /// extract binary data from request
 /// async fn index(body: Bytes) -> String {
@@ -135,10 +129,7 @@ impl<Err: ErrorRenderer> FromRequest<Err> for Bytes {
     >;
 
     #[inline]
-    fn from_request(
-        req: &HttpRequest,
-        payload: &mut crate::http::Payload,
-    ) -> Self::Future {
+    fn from_request(req: &HttpRequest, payload: &mut crate::http::Payload) -> Self::Future {
         let tmp;
         let cfg = if let Some(cfg) = req.app_data::<PayloadConfig>() {
             cfg
@@ -192,10 +183,7 @@ impl<Err: ErrorRenderer> FromRequest<Err> for String {
     >;
 
     #[inline]
-    fn from_request(
-        req: &HttpRequest,
-        payload: &mut crate::http::Payload,
-    ) -> Self::Future {
+    fn from_request(req: &HttpRequest, payload: &mut crate::http::Payload) -> Self::Future {
         let tmp;
         let cfg = if let Some(cfg) = req.app_data::<PayloadConfig>() {
             cfg
@@ -380,9 +368,7 @@ impl Future for HttpMessageBody {
 
         if let Some(len) = self.length.take() {
             if len > self.limit {
-                return Poll::Ready(Err(PayloadError::from(
-                    error::PayloadError::Overflow,
-                )));
+                return Poll::Ready(Err(PayloadError::from(error::PayloadError::Overflow)));
             }
         }
 
@@ -408,10 +394,9 @@ impl Future for HttpMessageBody {
 
 #[cfg(test)]
 mod tests {
-    use bytes::Bytes;
-
     use super::*;
     use crate::http::header;
+    use crate::util::Bytes;
     use crate::web::test::{from_request, TestRequest};
 
     #[crate::rt_test]
