@@ -7,7 +7,7 @@ use crate::http::body::MessageBody;
 use crate::http::error::{BlockingError, ResponseError};
 use crate::http::header::ContentEncoding;
 use crate::http::{Method, Request, Response};
-use crate::{IntoServiceFactory, Service, ServiceFactory};
+use crate::service::{IntoServiceFactory, ServiceFactory};
 
 use super::config::AppConfig;
 use super::error::ErrorRenderer;
@@ -261,7 +261,7 @@ where
     I: Send + 'static,
     E: Send + std::fmt::Debug + 'static,
 {
-    match ntex_rt::task::spawn_blocking(f).await {
+    match crate::rt::spawn_blocking(f).await {
         Ok(res) => res.map_err(BlockingError::Error),
         Err(_) => Err(BlockingError::Canceled),
     }
@@ -285,13 +285,11 @@ where
 pub fn server<F, I, S, B>(factory: F) -> HttpServer<F, I, S, B>
 where
     F: Fn() -> I + Send + Clone + 'static,
-    I: IntoServiceFactory<S>,
-    S: ServiceFactory<Config = AppConfig, Request = Request>,
-    S::Error: ResponseError + 'static,
+    I: IntoServiceFactory<S, Request, AppConfig>,
+    S: ServiceFactory<Request, AppConfig> + 'static,
+    S::Error: ResponseError,
     S::InitError: fmt::Debug,
-    S::Response: Into<Response<B>> + 'static,
-    S::Future: 'static,
-    <S::Service as Service>::Future: 'static,
+    S::Response: Into<Response<B>>,
     B: MessageBody + 'static,
 {
     HttpServer::new(factory)
